multidim.covertree.CoverTree.plot_tree — GDA Toolbox v1.0 Manual

# multidim.covertree.CoverTree.plot_tree

`CoverTree.` `plot_tree`(canvas, show_balls=True, show_tribes=False, show_villages=False, show_adults=True)

  Plot the tree of a CoverTree.

  Parameters: | canvas : `bokeh.plotting.figure.Figure` as obtained from `canvas = bokeh.plotting.figure()` show_balls : boolean default True show_adults : boolean default True show_villages : boolean default False show_tribes : boolean default False

#### Previous topic

multidim.covertree.CoverTree.plot

#### Next topic

multidim.covertree.CoverTree.reset